﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using HeuristicLab.Common;
using HeuristicLab.Random;

namespace HeuristicLab.Problems.Instances.DataAnalysis {
  public class Feynman8 : FeynmanDescriptor{
 public override string Name { get { return "Feynman I.12.1 F = mu*Nm"; } }

 protected override string TargetVariable { get { return "F"; } }
    protected override string[] VariableNames { get { return new string[] { "mu", "Nm", "F"}; } }
    protected override string[] AllowedInputVariables { get { return new string[] {"mu", "Nm"}; } }

    public int Seed { get; private set; }

    public Feynman8() : this((int)System.DateTime.Now.Ticks) { }

    public Feynman8(int seed) {
      Seed = seed;
    }

    protected override List<List<double>> GenerateValues() {
      var rand = new MersenneTwister((uint)Seed);

      var data = new List<List<double>>();
      var mu = ValueGenerator.GenerateUniformDistributedValues(rand.Next(), TestPartitionEnd, 1, 5).ToList();
      var Nm = ValueGenerator.GenerateUniformDistributedValues(rand.Next(), TestPartitionEnd, 1, 5).ToList();

      var F = new List<double>();

      data.Add(mu);
      data.Add(Nm);
      data.Add(F);

      for (var i = 0; i < mu.Count; i++) {
        var res = mu[i] * Nm[i];
        F.Add(res);
      }


      return data;
    }
  }
}
